@@ -4,7 +4,7 @@ Created on Sun Dec  4 17:12:37 2022
 
 init.py
 
-python-can-sontheim
+python-can-bluetooth
 """
 
 from .version import __version__
